local orig_calc_armor_dmg = PlayerDamage._calc_armor_damage
function PlayerDamage:_calc_armor_damage(attack_data,...)
	--mercenary calculations here
	if managers.player:get_temporary_property("kmerc_invuln") then
		return 0
	end
	--/
	
	local health_subtracted = 0

	if self:get_real_armor() > 0 then
		health_subtracted = self:get_real_armor()

		self:change_armor(-attack_data.damage)

		health_subtracted = health_subtracted - self:get_real_armor()

		self:_damage_screen()
		SoundDevice:set_rtpc("shield_status", self:armor_ratio() * 100)
		self:_send_set_armor()

		if self:get_real_armor() <= 0 then
			self._unit:sound():play("player_armor_gone_stinger")

			if attack_data.armor_piercing then
				self._unit:sound():play("player_sniper_hit_armor_gone")
			end

			local pm = managers.player

			self:_start_regen_on_the_side(pm:upgrade_value("player", "passive_always_regen_armor", 0))

			if pm:has_inactivate_temporary_upgrade("temporary", "armor_break_invulnerable") then
				pm:activate_temporary_upgrade("temporary", "armor_break_invulnerable")

				self._can_take_dmg_timer = pm:temporary_upgrade_value("temporary", "armor_break_invulnerable", 0)
			end
		end
	end

	managers.hud:damage_taken()

	return health_subtracted
end

local orig_calc_health_dmg = PlayerDamage._calc_health_damage
function PlayerDamage:_calc_health_damage(attack_data,...)
	--mercenary calculations here
	if managers.player:get_temporary_property("kmerc_invuln") then
		return 0
	end
	
	if managers.player:has_category_upgrade("player","kmerc_reactive_absorption") then
		local max_health = self:_max_health()
		
		local base_damage = attack_data.damage
		local new_damage = (base_damage * max_health) / (base_damage + max_health)
--		Print("Old damage",base_damage,"New damage",new_damage)
		attack_data.damage = new_damage
	end
	--/
	
	if attack_data.weapon_unit then
		local weap_base = alive(attack_data.weapon_unit) and attack_data.weapon_unit:base()
		local weap_tweak_data = weap_base and weap_base.weapon_tweak_data and weap_base:weapon_tweak_data()

		if weap_tweak_data and weap_tweak_data.slowdown_data then
			self:apply_slowdown(weap_tweak_data.slowdown_data)
		end
	end

	if managers.player:has_activate_temporary_upgrade("temporary", "mrwi_health_invulnerable") then
		return 0
	end

	local health_subtracted = 0
	health_subtracted = self:get_real_health()
	
	
	--mercenary invuln proc here
	local kmerc_proc_invuln = false
	if attack_data.damage >= health_subtracted then
		if managers.player:has_category_upgrade("player","kmerc_fatal_triggers_invuln") then
			local kmerc_invuln_data = managers.player:upgrade_value("player","kmerc_fatal_triggers_invuln")
			if managers.player:get_property("kmerc_invuln_ready") then
				local endure_health = kmerc_invuln_data.hp
				local max_invuln_duration = kmerc_invuln_data.duration
				--trigger invuln
				--set hp to 1
				managers.player:set_property("kmerc_invuln_ready",false)
				managers.player:activate_temporary_property("kmerc_invuln",max_invuln_duration,max_invuln_duration)
				--save the max duration to the temp property as both the value and the timer so that we can update the hud without having to get the upgrade data
				self:set_health(endure_health)
				
				--if sprinting, stop sprinting
				local mov_ext = self._unit:movement()
				if mov_ext and mov_ext:running() then
					local player_state = mov_ext:current_state()
					player_state:_end_action_running(managers.player:player_timer():time())
					player_state:set_running(false)
				end
				
				kmerc_proc_invuln = true
			end
		end
	end
	if not kmerc_proc_invuln then
		self:change_health(-attack_data.damage)
	end
	--/
	
--	self:change_health(-attack_data.damage)

	health_subtracted = health_subtracted - self:get_real_health()

	if managers.player:has_activate_temporary_upgrade("temporary", "copr_ability") and health_subtracted > 0 then
		local teammate_heal_level = managers.player:upgrade_level_nil("player", "copr_teammate_heal")

		if teammate_heal_level and self:get_real_health() > 0 then
			self._unit:network():send("copr_teammate_heal", teammate_heal_level)
		end
	end

	if self._has_mrwi_health_invulnerable then
		local health_threshold = self._mrwi_health_invulnerable_threshold or 0.5
		local is_cooling_down = managers.player:get_temporary_property("mrwi_health_invulnerable", false)

		if self:health_ratio() <= health_threshold and not is_cooling_down then
			local cooldown_time = self._mrwi_health_invulnerable_cooldown or 10

			managers.player:activate_temporary_upgrade("temporary", "mrwi_health_invulnerable")
			managers.player:activate_temporary_property("mrwi_health_invulnerable", cooldown_time, true)
		end
	end

	local trigger_skills = table.contains({
		"bullet",
		"explosion",
		"melee",
		"delayed_tick"
	}, attack_data.variant)

	if self:get_real_health() == 0 and trigger_skills then
		self:_chk_cheat_death()
	end

	self:_damage_screen()
	self:_check_bleed_out(trigger_skills)
	managers.hud:set_player_health({
		current = self:get_real_health(),
		total = self:_max_health(),
		revives = Application:digest_value(self._revives, false)
	})
	self:_send_set_health()
	self:_set_health_effect()
	managers.statistics:health_subtracted(health_subtracted)

	
	--mercenary strong side
	if not kmerc_proc_invuln and managers.player:has_category_upgrade("player","kmerc_bloody_armor") then
		if health_subtracted > 0 then
			if self:health_ratio() <= 0.5 then
				self:change_armor(health_subtracted)
			end
		end
	end
	--/

	return health_subtracted
end

Hooks:PostHook(PlayerDamage,"_check_update_max_health","kmerc_playerdamage_check_max_health",function(self)
	if not managers.player:get_property("kmerc_invuln_ready") then
		if self:full_health() then
			managers.player:set_property("kmerc_invuln_ready",true)
		end
	end
end)

Hooks:PostHook(PlayerDamage,"_upd_health_regen","kmerc_playerdamage_update_health_regen",function(self,t,dt)
	if managers.player:has_category_upgrade("player","kmerc_armored_hot") then
		local upgrade_data = managers.player:upgrade_value("player","kmerc_armored_hot")
		local interval = upgrade_data.interval
		local hot_percent = upgrade_data.hot_percent
		local warmup = upgrade_data.warmup
		
		if self:get_real_armor() > 0 then
			if not self:full_health() then
				local check_t = self._kmerc_upd_health_regen_timer or interval
				if check_t <= 0 then
					self._kmerc_upd_health_regen_timer = interval
					local max_armor = self:_max_armor()
					local hot_amount = max_armor * hot_percent
					
--					Print("Regen percent",hot_percent,"total",hot_amount)
					
					self:restore_health(hot_amount,true,true)
				else
					self._kmerc_upd_health_regen_timer = check_t - dt
				end
			end
		else
			self._kmerc_upd_health_regen_timer = warmup + interval
		end
	end
--	Console:SetTracker(string.format("Regen timer: %0.2f",self._kmerc_upd_health_regen_timer or -1),3)
	
	
--	local d = 0
	local max_invuln_duration = managers.player:get_temporary_property("kmerc_invuln",false)
	if max_invuln_duration then
		local invuln_duration_left = managers.player._temporary_properties._properties.kmerc_invuln[2] - Application:time()
		--i'm pretty sure the "t" that's passed to _upd_health_regen() is the timermanager timer, not the application timer
--		d = invuln_duration_left
		
--		local kmerc_invuln_data = managers.player:upgrade_value("player","kmerc_fatal_triggers_invuln")
--		local invuln_duration = kmerc_invuln_data.duration
		
		managers.hud:set_player_custom_radial({
			total = 1,
			current = invuln_duration_left / max_invuln_duration
		})
	end
	
--	Console:SetTracker(string.format("invuln remaining: %0.2f",d,1))
--	Console:SetTracker("invuln ready: " .. tostring(managers.player:get_property("kmerc_invuln_ready") and true or false),2)
end)

local orig_is_suppressed = PlayerDamage.is_suppressed
function PlayerDamage:is_suppressed(...)
	if managers.player:has_category_upgrade("player","kmerc_suppression_immunity") then 
		return false
	else
		return orig_is_suppressed(self,...)
	end
end